// Initialize the application
document.addEventListener('DOMContentLoaded', () => {
    // Update current time every second
    updateTime();
    setInterval(updateTime, 1000);

    // Initialize menu click handlers
    initializeMenuHandlers();

    // Load default page (overview)
    loadPage('overview');
});

// Update current time
function updateTime() {
    const timeElement = document.getElementById('current-time');
    if (timeElement) {
        const now = new Date();
        const timeString = now.toLocaleTimeString('ko-KR', {
            hour: '2-digit',
            minute: '2-digit',
            second: '2-digit'
        });
        timeElement.textContent = timeString;
    }
}

// Initialize menu click handlers
function initializeMenuHandlers() {
    document.querySelectorAll('.nav-link').forEach(link => {
        link.addEventListener('click', (e) => {
            e.preventDefault();
            
            // Remove active class from all links
            document.querySelectorAll('.nav-link').forEach(l => l.classList.remove('active'));
            
            // Add active class to clicked link
            link.classList.add('active');
            
            // Load the corresponding page
            const page = link.dataset.page;
            loadPage(page);
        });
    });

    // Logout button handler
    const logoutBtn = document.getElementById('logout-btn');
    if (logoutBtn) {
        logoutBtn.addEventListener('click', () => {
            window.location.href = 'index.php';
        });
    }
}

// Load different pages
function loadPage(page) {
    const contentArea = document.getElementById('content-area');
    contentArea.innerHTML = '';

    switch(page) {
        case 'overview':
            contentArea.innerHTML = `
                <div class="overview-container">
                    <div class="map-background">
                        <img src="assets/images/utron_map.jpg" alt="Factory Map" class="map-image">
                        <div class="card-panels"></div>
                    </div>
                </div>
            `;
            loadOverviewData();
            break;
        case 'monitoring':
            contentArea.innerHTML = `
                <div class="monitoring-container">
                    <div class="factory-list">
                        <div class="factory-list-header">
                            <h5>공장 목록</h5>
                            <button class="btn btn-sm btn-outline-secondary" id="clear-filter" style="display: none;">
                                <i class="bi bi-x"></i>
                            </button>
                        </div>
                        <div class="factory-buttons" id="factory-buttons">
                            <!-- Factory buttons will be loaded here -->
                        </div>
                    </div>
                    <div class="monitoring-content">
                        <div class="monitoring-header">
                            <div class="card">
                                <div class="card-body p-2">
                                    <div class="d-flex align-items-center gap-3">
                                        <button class="btn btn-primary" id="refresh-btn">
                                            <i class="bi bi-arrow-clockwise"></i> 새로고침
                                        </button>
                                        <div class="form-check form-switch">
                                            <input class="form-check-input" type="checkbox" id="auto-refresh" checked>
                                            <label class="form-check-label" for="auto-refresh">자동 갱신 (5초)</label>
                                        </div>
                                        <div class="last-update" id="last-update"></div>
                                    </div>
                                </div>
                            </div>
                            <div class="card">
                                <div class="card-body p-2">
                                    <div class="d-flex align-items-center gap-3">
                                        <div class="form-check">
                                            <input class="form-check-input" type="checkbox" id="detailed-view">
                                            <label class="form-check-label" for="detailed-view">자세히 보기</label>
                                        </div>
                                        <button class="btn btn-success" id="export-btn">
                                            <i class="bi bi-file-excel"></i> 엑셀 저장
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="table-responsive">
                            <table class="table table-striped table-hover" id="monitoring-table">
                                <thead>
                                    <tr>
                                        <th>공장명</th>
                                        <th>상세위치</th>
                                        <th>배출구번호</th>
                                        <th>운전상태</th>
                                        <th>통신상태</th>
                                        <th>데이터시각</th>
                                        <th>전일가동시간</th>
                                        <th>금일가동시간</th>
                                        <th>전일사용량(kWh)</th>
                                        <th>금일사용량(kWh)</th>
                                        <th class="detailed-column">전력량계번호</th>
                                        <th class="detailed-column">현재전류값</th>
                                        <th class="detailed-column">가동기준전류</th>
                                        <th class="detailed-column">전력량계Scale</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <!-- Data will be loaded here -->
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            `;
            loadMonitoringData();
            setupMonitoringControls();
            break;
        // ... other cases ...
    }
}

// Load overview data
function loadOverviewData() {
    fetch('api/get_tag_list.php')
        .then(response => response.json())
        .then(data => {
            // Group data by factory
            const factoryGroups = {};
            data.forEach(item => {
                if (!factoryGroups[item.공장명]) {
                    factoryGroups[item.공장명] = [];
                }
                factoryGroups[item.공장명].push(item);
            });

            // Create card panels for each factory
            const cardPanels = document.querySelector('.card-panels');
            
            // Define factory coordinates based on Flutter layout
            const factoryCoordinates = {
                '버스 (버스1 도장)': { x: 1440, y: 670 },
                '버스 (버스 TEST동)': { x: 1240, y: 670 },
                '엔진 (엔진1)': { x: 1000, y: 600 },
                '엔진 (엔진2)': { x: 600, y: 600 },
                '기타': { x: 374, y: 371 },
                '소재': { x: 1000, y: 850 },
                '트럭 (트럭1 도장)': { x: 744, y: 154 },
                '트럭 (트럭2 5천톤 도장)': { x: 744, y: 371 }
            };

            // Assuming the map image is 1920x1080 (standard HD resolution)
            const maxWidth = 1920;
            const maxHeight = 1080;

            Object.entries(factoryGroups).forEach(([factoryName, items]) => {
                const totalCount = items.length;
                // 통신상태가 '정상'인 경우만 카운트
                const normalCommCount = items.filter(item => item.통신상태 === '정상').length;
                // 운전상태가 'ON'인 경우만 카운트
                const operationalCount = items.filter(item => item.운전상태 === 'ON').length;

                // Get coordinates from predefined map
                const coords = factoryCoordinates[factoryName];
                if (coords) {
                    // Convert absolute coordinates to percentage
                    const x = (coords.x / maxWidth) * 100;
                    const y = (coords.y / maxHeight) * 100;
                    
                    const card = document.createElement('div');
                    card.className = 'factory-card';
                    card.style.left = `${x}%`;
                    card.style.top = `${y}%`;
                    
                    // 통신 상태에 따라 카드 색상 변경
                    const commStatus = normalCommCount === totalCount ? 'success' : 
                                     normalCommCount === 0 ? 'danger' : 'warning';
                    card.classList.add(`comm-${commStatus}`);
                    
                    card.innerHTML = `
                        <div class="card-header">${factoryName}</div>
                        <div class="card-body">
                            <div class="status-item">
                                <i class="bi bi-building"></i>
                                <span>총 ${totalCount}개</span>
                            </div>
                            <div class="status-item">
                                <i class="bi bi-wifi"></i>
                                <span>통신 ${normalCommCount}개</span>
                            </div>
                            <div class="status-item">
                                <i class="bi bi-power"></i>
                                <span>운전 ${operationalCount}개</span>
                            </div>
                        </div>
                    `;
                    cardPanels.appendChild(card);
                }
            });
        })
        .catch(error => console.error('Error loading overview data:', error));
}

function loadMonitoringData(selectedFactory = null) {
    fetch('api/get_tag_list.php')
        .then(response => response.json())
        .then(data => {
            // Update last update time
            const now = new Date();
            document.getElementById('last-update').textContent = 
                `마지막 업데이트: ${now.toLocaleTimeString()}`;

            // Load factory buttons
            const factoryGroups = {};
            data.forEach(item => {
                if (!factoryGroups[item.공장명]) {
                    factoryGroups[item.공장명] = true;
                }
            });

            const factoryButtons = document.getElementById('factory-buttons');
            const clearFilterBtn = document.getElementById('clear-filter');
            factoryButtons.innerHTML = '';
            Object.keys(factoryGroups).forEach(factoryName => {
                const button = document.createElement('button');
                button.className = 'btn btn-outline-primary factory-btn';
                button.textContent = factoryName;
                button.onclick = () => loadMonitoringData(factoryName);
                if (selectedFactory === factoryName) {
                    button.classList.add('active');
                    clearFilterBtn.style.display = 'block';
                }
                factoryButtons.appendChild(button);
            });

            // Filter data if factory is selected
            if (selectedFactory) {
                data = data.filter(item => item.공장명 === selectedFactory);
            }

            // Load table data
            const tbody = document.querySelector('#monitoring-table tbody');
            tbody.innerHTML = '';
            data.forEach(item => {
                const row = document.createElement('tr');
                row.innerHTML = `
                    <td>${item.공장명 || ''}</td>
                    <td>${item.상세위치 || ''}</td>
                    <td>${item.배출구번호 || ''}</td>
                    <td class="status-cell ${item.운전상태 === 'ON' ? 'status-on' : 'status-off'}">
                        ${item.운전상태 || ''}
                    </td>
                    <td class="status-cell ${item.통신상태 === '정상' ? 'status-normal' : 'status-error'}">
                        ${item.통신상태 || ''}
                    </td>
                    <td>${item.데이터시각 || ''}</td>
                    <td>${item.전일가동시간 || 0}</td>
                    <td>${item.금일가동시간 || 0}</td>
                    <td>${item['전일사용량(kWh)'] || 0}</td>
                    <td>${item['금일사용량(kWh)'] || 0}</td>
                    <td class="detailed-column">${item.전력량계번호 || ''}</td>
                    <td class="detailed-column">${item.현재전류값 || 0}</td>
                    <td class="detailed-column">${item.가동기준전류 || 0}</td>
                    <td class="detailed-column">${item.전력량계Scale || 0}</td>
                `;
                tbody.appendChild(row);
            });
        })
        .catch(error => console.error('Error loading monitoring data:', error));
}

function setupMonitoringControls() {
    let autoRefreshInterval;
    const autoRefreshCheckbox = document.getElementById('auto-refresh');
    const refreshBtn = document.getElementById('refresh-btn');
    const exportBtn = document.getElementById('export-btn');
    const clearFilterBtn = document.getElementById('clear-filter');
    const detailedViewCheckbox = document.getElementById('detailed-view');

    // Auto refresh toggle
    autoRefreshCheckbox.addEventListener('change', (e) => {
        if (e.target.checked) {
            autoRefreshInterval = setInterval(loadMonitoringData, 5000);
        } else {
            clearInterval(autoRefreshInterval);
        }
    });

    // Manual refresh
    refreshBtn.addEventListener('click', () => {
        loadMonitoringData();
    });

    // Clear filter
    clearFilterBtn.addEventListener('click', () => {
        clearFilterBtn.style.display = 'none';
        loadMonitoringData();
    });

    // Detailed view toggle
    detailedViewCheckbox.addEventListener('change', (e) => {
        const detailedColumns = document.querySelectorAll('.detailed-column');
        detailedColumns.forEach(col => {
            col.style.display = e.target.checked ? 'table-cell' : 'none';
        });
    });

    // Export to Excel
    exportBtn.addEventListener('click', () => {
        const table = document.getElementById('monitoring-table');
        const wb = XLSX.utils.table_to_book(table, {sheet: "Sheet1"});
        XLSX.writeFile(wb, "monitoring_data.xlsx");
    });

    // Start auto refresh
    autoRefreshInterval = setInterval(loadMonitoringData, 5000);
} 